@@ -77,3 +77,32 @@
 #' ```
 #'
 "tiny.table"
+
+
+
+#' abstract.table
+#'
+#' Example data to create abstract books
+#'
+#' @md
+#' @details
+#' ```{r echo=FALSE}
+#' knitr::kable(abstract.table)
+#' ```
+#'
+"abstract.table"
+
+
+
+#' multichoice.table
+#'
+#' Example data to create multiple choice tests
+#'
+#' @md
+#' @details
+#' ```{r echo=FALSE}
+#' knitr::kable(multichoice.table)
+#' ```
+#'
+"multichoice.table"
+
